=======
Credits
=======

Development Lead
----------------
* `Mark van Koningsveld`_

.. _Mark van Koningsveld: https://www.tudelft.nl/citg/over-faculteit/afdelingen/hydraulic-engineering/sections/rivers-ports-waterways-and-dredging-engineering/staff/van-koningsveld-m/

Contributors
------------

Various MSc projects

* `Wijnand Ijzermans`_, 2019. **Terminal design optimization. Adaptive agribulk terminal planning in light of an uncertain future.** MSc thesis. Delft University of Technology, Civil Engineering and Geosciences, Hydraulic Engineering - Ports and Waterways. Delft, the Netherlands.
* `Stephanie Lanphen`_, 2019. **Hydrogen import terminal. Elaborating the supply chains of a hydrogen import terminal, and its corresponding investment decisions.** MSc thesis. Delft University of Technology, Civil Engineering and Geosciences, Hydraulic Engineering - Ports and Waterways. Delft, the Netherlands.
* `Piebe Koster`_, 2019. **Optimisation of concept level container terminal design. Accelerate the generation and visualisation of the terminal design to reduce the probability of a sub-optimal solution.** MSc thesis. Delft University of Technology, Civil Engineering and Geosciences, Hydraulic Engineering - Ports and Waterways. Delft, the Netherlands.

.. _Wijnand Ijzermans: http://resolver.tudelft.nl/uuid:7ad9be30-7d0a-4ece-a7dc-eb861ae5df24
.. _Stephanie Lanphen: http://resolver.tudelft.nl/uuid:d2429b05-1881-4e42-9bb3-ed604bc15255
.. _Piebe Koster: https://repository.tudelft.nl

Ongoing MSc work

* `Hugo Stam`_, 2019. **Logistical optimisation of offshore onshore port systems from a economic perspective.** MSc thesis. Delft University of Technology, Civil Engineering and Geosciences, Environmental Fluid Mechanics. Delft, the Netherlands.

.. _Hugo Stam: https://repository.tudelft.nl

